"""Module for detecting the phone number."""

from typing import Any, Dict, List, Tuple

import regex as re

from src.detections import PhoneNumberDetection
from src.detectors.interface import Detector


PHONE_NUMBER_REGEX = re.compile(
    r"(?P<country_code>(00[1-9]\d?)|(\(?([+\d]{2,3})\)?)[- ]??)?"
    r"(?P<number>(\d[- ]??){9,10})"
)


class PhoneNumberDetector(Detector):
    """Detector for phone numbers."""

    def detect(
        self, text: str, annotations: Dict[str, List[Tuple[int, int, Any]]]
    ) -> List[Tuple[int, int, PhoneNumberDetection]]:
        """Detects phone numbers in the text.

        Args:
            text (str): the text to be searched
            annotations (Dict[str, List[Tuple[int, int, Any]]]): Annotations of
                the text

        Returns:
            List[Tuple[int, int, PhoneNumberDetection]]: a list of tuples
                containing (start, end, entity_type)

        """
        matches = PHONE_NUMBER_REGEX.finditer(text)
        phone_numbers = []
        for match in matches:
            phone_numbers.append((match.start(), match.end(), PhoneNumberDetection()))
        return phone_numbers
